"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.versionInfo = exports.ddgraph = void 0;

var _utils = require("./utils");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var ddgraphInitialState = {
  isGraphView: true,
  layoutInitialized: false,
  nodes: [],
  edges: [],
  graphBoundingBox: [],
  legendItems: [],
  hoveringNode: null,
  highlightingNode: null,
  relatedNodeIDs: [],
  secondHighlightingNodeID: null,
  dataModelStructure: null,
  overlayPropertyHidden: true,
  canvasBoundingRect: {
    top: 0,
    left: 0
  },
  needReset: false,
  tableExpandNodeID: null,
  searchHistoryItems: (0, _utils.getSearchHistoryItems)(),
  graphNodesSVGElements: null,
  currentSearchKeyword: '',
  searchResult: [],
  matchedNodeIDs: [],
  matchedNodeIDsInProperties: [],
  matchedNodeIDsInNameAndDescription: [],
  isSearchMode: false,
  isSearching: false,
  highlightingMatchedNodeID: null,
  highlightingMatchedNodeOpened: false
};

var ddgraph = function ddgraph() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : ddgraphInitialState;
  var action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case 'TOGGLE_GRAPH_TABLE_VIEW':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          isGraphView: action.isGraphView,
          overlayPropertyHidden: true
        });
      }

    case 'GRAPH_LAYOUT_CALCULATED':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          nodes: action.nodes,
          edges: action.edges,
          graphBoundingBox: action.graphBoundingBox,
          layoutInitialized: true
        });
      }

    case 'GRAPH_LEGEND_CALCULATED':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          legendItems: action.legendItems
        });
      }

    case 'GRAPH_UPDATE_HOVERING_NODE':
      {
        var newHoveringNode = state.nodes.find(function (n) {
          return n.id === action.nodeID;
        });
        return _objectSpread(_objectSpread({}, state), {}, {
          hoveringNode: newHoveringNode
        });
      }

    case 'GRAPH_UPDATE_CANVAS_BOUNDING_RECT':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          canvasBoundingRect: action.canvasBoundingRect
        });
      }

    case 'GRAPH_UPDATE_RELATED_HIGHLIGHTING_NODE':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          relatedNodeIDs: action.relatedNodeIDs
        });
      }

    case 'GRAPH_UPDATE_SECOND_HIGHLIGHTING_NODE_CANDIDATES':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          secondHighlightingNodeCandidateIDs: action.secondHighlightingNodeCandidateIDs
        });
      }

    case 'GRAPH_UPDATE_PATH_RELATED_TO_SECOND_HIGHLIGHTING_NODE':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          pathRelatedToSecondHighlightingNode: action.pathRelatedToSecondHighlightingNode
        });
      }

    case 'GRAPH_UPDATE_DATA_MODEL_STRUCTURE':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          dataModelStructure: action.dataModelStructure,
          dataModelStructureRelatedNodeIDs: action.dataModelStructureRelatedNodeIDs,
          dataModelStructureAllRoutesBetween: action.routesBetweenStartEndNodes
        });
      }

    case 'GRAPH_SET_OVERLAY_PROPERTY_TABLE_HIDDEN':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          overlayPropertyHidden: action.isHidden
        });
      }

    case 'GRAPH_CANVAS_RESET_REQUIRED':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          needReset: action.needReset
        });
      }

    case 'GRAPH_RESET_HIGHLIGHT':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          highlightingNode: null,
          secondHighlightingNodeID: null,
          tableExpandNodeID: null
        });
      }

    case 'GRAPH_CLICK_NODE':
      {
        if (state.isSearchMode) {
          // clicking node in search mode opens property table
          return _objectSpread(_objectSpread({}, state), {}, {
            highlightingMatchedNodeID: action.nodeID,
            highlightingMatchedNodeOpened: false,
            overlayPropertyHidden: false
          });
        }

        var newHighlightingNode = null;
        var newSecondHighlightingNodeID = null;

        if (action.nodeID) {
          // if no node is selected, select this node as highlight node
          if (!state.highlightingNode) {
            newHighlightingNode = state.nodes.find(function (n) {
              return n.id === action.nodeID;
            });
          } else if (state.highlightingNode) {
            newHighlightingNode = state.highlightingNode; // if is clicking the same node

            if (state.highlightingNode.id === action.nodeID) {
              // if no second node is selected, regard this as cancel selecting
              if (!state.secondHighlightingNodeID) {
                newHighlightingNode = null;
              }
            } else if (state.secondHighlightingNodeCandidateIDs.length > 1 && state.secondHighlightingNodeCandidateIDs.includes(action.nodeID)) {
              // regard as canceling selecting second highlight node
              if (state.secondHighlightingNodeID === action.nodeID) {
                newSecondHighlightingNodeID = null;
              } else {
                // select this as second highlight node
                newSecondHighlightingNodeID = action.nodeID;
              }
            }
          }
        }

        var newTableExpandNodeID = newHighlightingNode ? newHighlightingNode.id : null;
        return _objectSpread(_objectSpread({}, state), {}, {
          highlightingNode: newHighlightingNode,
          secondHighlightingNodeID: newSecondHighlightingNodeID,
          tableExpandNodeID: newTableExpandNodeID
        });
      }

    case 'GRAPH_CLICK_BLANK_SPACE':
      {
        var _newHighlightingNode = state.highlightingNode;
        var _newSecondHighlightingNodeID = state.secondHighlightingNodeID;
        var _newTableExpandNodeID = state.tableExpandNodeID;

        if (state.highlightingNode) {
          if (state.secondHighlightingNodeID) {
            _newSecondHighlightingNodeID = null;
          } else {
            _newHighlightingNode = null;
            _newTableExpandNodeID = null;
          }
        }

        return _objectSpread(_objectSpread({}, state), {}, {
          highlightingNode: _newHighlightingNode,
          secondHighlightingNodeID: _newSecondHighlightingNodeID,
          tableExpandNodeID: _newTableExpandNodeID
        });
      }

    case 'TABLE_EXPAND_NODE':
      {
        var _newHighlightingNode2 = null;

        if (action.nodeID) {
          _newHighlightingNode2 = state.nodes.find(function (n) {
            return n.id === action.nodeID;
          });
        }

        return _objectSpread(_objectSpread({}, state), {}, {
          tableExpandNodeID: action.nodeID,
          highlightingNode: _newHighlightingNode2,
          secondHighlightingNodeID: null
        });
      }

    case 'SEARCH_SET_IS_SEARCHING_STATUS':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          isSearching: action.isSearching
        });
      }

    case 'SEARCH_RESULT_UPDATED':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          searchResult: action.searchResult,
          matchedNodeIDs: action.searchResultSummary.generalMatchedNodeIDs,
          matchedNodeIDsInNameAndDescription: action.searchResultSummary.matchedNodeIDsInNameAndDescription,
          matchedNodeIDsInProperties: action.searchResultSummary.matchedNodeIDsInProperties,
          isGraphView: true,
          isSearchMode: true,
          highlightingMatchedNodeID: null,
          highlightingMatchedNodeOpened: false,
          highlightingNode: null,
          secondHighlightingNodeID: null,
          tableExpandNodeID: null
        });
      }

    case 'SEARCH_CLEAR_HISTORY':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          searchHistoryItems: (0, _utils.clearSearchHistoryItems)()
        });
      }

    case 'SEARCH_HISTORY_ITEM_CREATED':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          searchHistoryItems: (0, _utils.addSearchHistoryItems)(action.searchHistoryItem)
        });
      }

    case 'GRAPH_NODES_SVG_ELEMENTS_UPDATED':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          graphNodesSVGElements: action.graphNodesSVGElements
        });
      }

    case 'SEARCH_RESULT_CLEARED':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          searchResult: [],
          matchedNodeIDs: [],
          currentSearchKeyword: '',
          isSearchMode: false,
          highlightingMatchedNodeID: null,
          highlightingMatchedNodeOpened: false
        });
      }

    case 'SEARCH_SAVE_CURRENT_KEYWORD':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          currentSearchKeyword: action.keyword
        });
      }

    case 'GRAPH_MATCHED_NODE_OPENED':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          highlightingMatchedNodeOpened: action.opened
        });
      }

    default:
      return state;
  }
};

exports.ddgraph = ddgraph;

var versionInfo = function versionInfo() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case 'RECEIVE_VERSION_INFO':
      return _objectSpread(_objectSpread({}, state), {}, {
        dictionaryVersion: action.data.dictionary.version || 'unknown',
        apiVersion: action.data.version || 'unknown'
      });

    default:
      return state;
  }
};

exports.versionInfo = versionInfo;