"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.moduleReducers = void 0;

var _lodash = _interopRequireDefault(require("lodash"));

var _bentoComponents = require("bento-components");

var actionTypes = _interopRequireWildcard(require("../actions/actionTypes"));

var _modelExplorerUtil = require("../../utils/modelExplorerUtil");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var initialState = {
  allActiveFilters: {},
  unfilteredDictionary: {},
  filteredDictionary: {},
  activeFilter: false,
  filtersCleared: false,
  filterGroup: '',
  filterHashMap: new Map(),
  filterConfig: {}
};
var defaultFilterConfig = {
  facetSearchData: [],
  facetSectionVariables: {},
  resetIcon: {},
  baseFilters: {},
  filterSections: [],
  filterOptions: []
}; // sorting variables

var sortTypes = {
  SUBJECTS: 'subjects',
  NAME: 'name',
  COUNT: 'count'
};
/**
 * Sort checkboxes by single section
 *
 * @param {array} checkboxData
 * @return {array}
 */

var sortBySection = function sortBySection(checkboxData, sortType) {
  if (sortType === sortTypes.SUBJECTS) {
    checkboxData.sort(function (a, b) {
      return b.subjects - a.subjects;
    });
  } else {
    checkboxData.sort(function (a, b) {
      return a.name > b.name || -(a.name < b.name);
    });
  }

  checkboxData = sortByCheckedItem(checkboxData);
  return checkboxData;
};
/**
 * Sort checkboxes by Checked
 *
 * @param {array} checkboxData
 * @return {array} 
 */


var sortByCheckedItem = function sortByCheckedItem(checkboxData) {
  return checkboxData.sort(function (a, b) {
    return b.isChecked - a.isChecked;
  });
};
/**
 * sort all the checkbox in facet search 
 * @param {array} checkboxData 
 * @param {object} sortByList 
 * @returns 
 */


var sortFacetSections = function sortFacetSections(checkboxData, sortByList) {
  var sortCheckBoxItem = _lodash.default.cloneDeep(checkboxData);

  sortCheckBoxItem.forEach(function (item) {
    var sortType = sortByList && sortByList[item.datafield] === sortTypes.COUNT ? sortTypes.SUBJECTS : sortTypes.NAME;
    item.checkboxItems = sortBySection(item.checkboxItems, sortType);
  });
  return sortCheckBoxItem;
};
/**
 * toggle check box action
 * @param {object} state 
 * @param {*} action 
 * @returns
 */


var toggleCheckBox = function toggleCheckBox(payload, state) {
  var allActiveFilters = (0, _modelExplorerUtil.toggleCheckBoxAction)(payload, state);
  var updatedCheckboxData = (0, _bentoComponents.setSelectedFilterValues)(state.facetfilterConfig.facetSearchData, allActiveFilters);
  var filtered = (0, _modelExplorerUtil.generateSubjectCountsAndFilterData)(state, allActiveFilters, payload);
  var sortCheckboxData = (0, _modelExplorerUtil.setSubjectCount)(updatedCheckboxData, filtered.subjectCounts);
  updatedCheckboxData = sortFacetSections(sortCheckboxData, state.sortByList);

  var updateState = _objectSpread(_objectSpread({}, state), {}, {
    dictionary: filtered.dictionary,
    allActiveFilters: allActiveFilters,
    checkbox: {
      data: (0, _modelExplorerUtil.setSubjectCount)(updatedCheckboxData, filtered.subjectCounts)
    }
  });

  return updateState;
};

var moduleReducers = function moduleReducers() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments.length > 1 ? arguments[1] : undefined;
  var payload = action.payload;
  var filtered;

  switch (action.type) {
    case actionTypes.RECEIVE_DICTIONARY:
      var filterConfig = payload && payload.facetfilterConfig ? payload.facetfilterConfig : defaultFilterConfig;
      var dictionary = (0, _modelExplorerUtil.getDictionaryWithExcludeSystemProperties)(payload.data);
      filtered = (0, _modelExplorerUtil.generateSubjectCountsAndFilterData)(dictionary);
      return _objectSpread(_objectSpread({}, state), {}, {
        dictionary: dictionary,
        properties: payload.properties,
        nodeTypes: (0, _modelExplorerUtil.getNodeTypes)(payload.data),
        file_nodes: (0, _modelExplorerUtil.getFileNodes)(payload.data),
        allActiveFilters: (0, _modelExplorerUtil.getAllFilters)(filterConfig.facetSearchData),
        unfilteredDictionary: dictionary,
        filteredDictionary: dictionary,
        filterHashMap: (0, _modelExplorerUtil.initializeFilterHashMap)(dictionary, filterConfig.filterSections),
        subjectCountObject: filtered,
        facetfilterConfig: filterConfig,
        checkbox: {
          data: (0, _modelExplorerUtil.setSubjectCount)(filterConfig.facetSearchData, filtered.subjectCounts)
        }
      });

    case actionTypes.FILTER_DATA_EXPLORER:
      return toggleCheckBox(payload, state);

    case actionTypes.CLEAR_ALL_FILTERS:
      filtered = (0, _modelExplorerUtil.generateSubjectCountsAndFilterData)(state.unfilteredDictionary);
      var checkboxItems = sortFacetSections((0, _modelExplorerUtil.setSubjectCount)(state.facetfilterConfig.facetSearchData, filtered.subjectCounts), state.sortByList);
      return _objectSpread(_objectSpread({}, state), {}, {
        dictionary: state.unfilteredDictionary,
        filteredDictionary: state.unfilteredDictionary,
        subjectCountObject: filtered,
        allActiveFilters: state.facetfilterConfig.baseFilters,
        activeFilter: false,
        filtersCleared: true,
        checkbox: {
          data: checkboxItems
        },
        ortByList: _objectSpread({}, state.sortByList)
      });

    case actionTypes.SORT_SINGLE_SECTION:
      var groupData = state.checkbox.data.filter(function (group) {
        return payload.groupName === group.datafield;
      })[0];
      var _state = state,
          sortByList = _state.sortByList;
      sortByList = sortByList || {};
      var sortType = payload.sortBy === sortTypes.COUNT ? sortTypes.SUBJECTS : sortTypes.NAME;
      var sortedCheckboxItems = sortBySection(groupData.checkboxItems, sortType);
      sortByList[groupData.datafield] = payload.sortBy;
      var data = state.checkbox.data.map(function (group) {
        if (group.datafield === groupData.datafield) {
          var updatedGroupData = group;
          updatedGroupData.checkboxItems = sortedCheckboxItems;
          return updatedGroupData;
        }

        return group;
      });
      return _objectSpread(_objectSpread({}, state), {}, {
        checkbox: {
          data: data
        },
        sortByList: sortByList
      });

    case actionTypes.CLEAR_SECTION:
      var facetSection = payload.facetSection;

      if (state.sortByList && state.sortByList[facetSection.datafield]) {
        delete state.sortByList[facetSection.datafield];
      }

      var allFilters = state.allActiveFilters;
      allFilters[facetSection.datafield] = [];
      state = _objectSpread(_objectSpread({}, state), {}, {
        allActiveFilters: allFilters
      });
      return toggleCheckBox(payload, state);

    default:
      return state;
  }
};

exports.moduleReducers = moduleReducers;