"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getNodeTypes = exports.getFileNodes = exports.default = void 0;

var _redux = require("redux");

var _reducers = _interopRequireDefault(require("./DataDictionary/reducers"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var getFileNodes = function getFileNodes(dictionary) {
  return Object.keys(dictionary).filter(function (node) {
    return dictionary[node].category === 'data_file';
  });
};

exports.getFileNodes = getFileNodes;

var getNodeTypes = function getNodeTypes(dictionary) {
  return Object.keys(dictionary).filter(function (node) {
    return node.charAt(0) !== '_';
  });
};

exports.getNodeTypes = getNodeTypes;

var versionInfo = function versionInfo() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case 'RECEIVE_VERSION_INFO':
      return _objectSpread(_objectSpread({}, state), {}, {
        dictionaryVersion: action.data.dictionary.version || 'unknown',
        apiVersion: action.data.version || 'unknown'
      });

    default:
      return state;
  }
};

var excludeSystemProperties = function excludeSystemProperties(node) {
  var properties = node.properties && Object.keys(node.properties).filter(function (key) {
    return node.systemProperties ? !node.systemProperties.includes(key) : true;
  }).reduce(function (acc, key) {
    acc[key] = node.properties[key];
    return acc;
  }, {});
  return properties;
};

var getDictionaryWithExcludeSystemProperties = function getDictionaryWithExcludeSystemProperties(dictionary) {
  var ret = Object.keys(dictionary).map(function (nodeID) {
    var node = dictionary[nodeID];
    if (!node.properties) return node;
    return _objectSpread(_objectSpread({}, node), {}, {
      properties: excludeSystemProperties(node)
    });
  }).reduce(function (acc, node) {
    acc[node.id] = node;
    return acc;
  }, {});
  return ret;
};

var submission = function submission() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case 'REQUEST_UPLOAD':
      return _objectSpread(_objectSpread({}, state), {}, {
        file: action.file,
        file_type: action.file_type
      });

    case 'UPDATE_FILE':
      return _objectSpread(_objectSpread({}, state), {}, {
        file: action.file,
        file_type: action.file_type
      });

    case 'UPDATE_FORM_SCHEMA':
      return _objectSpread(_objectSpread({}, state), {}, {
        formSchema: _objectSpread(_objectSpread({}, state.formSchema), action.formSchema)
      });

    case 'RECEIVE_PROJECTS':
      return _objectSpread(_objectSpread({}, state), {}, {
        projects: action.data.reduce(function (map, p) {
          var res = map;
          res[p.code] = p.project_id;
          return res;
        }, {}),
        projectAvail: action.data.reduce(function (map, p) {
          var res = map;
          res[p.project_id] = p.availability_type;
          return res;
        }, {})
      });

    case 'RECEIVE_NODE_TYPES':
      return _objectSpread(_objectSpread({}, state), {}, {
        nodeTypes: action.data
      });

    case 'RECEIVE_DICTIONARY':
      return _objectSpread(_objectSpread({}, state), {}, {
        dictionary: getDictionaryWithExcludeSystemProperties(action.data),
        nodeTypes: getNodeTypes(action.data),
        file_nodes: getFileNodes(action.data)
      });

    case 'RECEIVE_AUTHORIZATION_URL':
      return _objectSpread(_objectSpread({}, state), {}, {
        oauth_url: action.url
      });

    case 'RECEIVE_SUBMISSION_LOGIN':
      return _objectSpread(_objectSpread({}, state), {}, {
        login: state.result,
        error: state.error
      });

    case 'RECEIVE_SUBMISSION':
      {
        var prevCounts = 'submit_entity_counts' in state ? state.submit_entity_counts : {};
        var newCounts = (action.data.entities || []).map(function (ent) {
          return ent.type || 'unknown';
        }).reduce(function (db, type) {
          var res = db;
          res[type] = (res[type] || 0) + 1;
          return res;
        }, prevCounts);
        var data = state.submit_result ? state.submit_result.concat(action.data.entities || []) : action.data.entities;
        var status = state.submit_status ? Math.max(state.submit_status, action.submit_status) : action.submit_status;
        return _objectSpread(_objectSpread({}, state), {}, {
          submit_entity_counts: newCounts,
          submit_result: data,
          submit_result_string: state.submit_result_string.concat(JSON.stringify(action.data, null, '    ')).concat('\n\n'),
          submit_status: status,
          submit_counter: state.submit_counter + 1,
          submit_total: action.total
        });
      }

    case 'SUBMIT_SEARCH_FORM':
      return _objectSpread(_objectSpread({}, state), {}, {
        search_form: action.data
      });

    case 'RECEIVE_SEARCH_ENTITIES':
      return _objectSpread(_objectSpread({}, state), {}, {
        search_result: action.data,
        search_status: action.search_status
      });

    case 'RECEIVE_COUNTS':
      return _objectSpread(_objectSpread({}, state), {}, {
        counts_search: action.data,
        links_search: Object.entries(action.data).reduce(function (acc, entry) {
          acc[entry[0]] = entry[1].length;
          return acc;
        }, {})
      });

    case 'CLEAR_COUNTS':
      return _objectSpread(_objectSpread({}, state), {}, {
        counts_search: null,
        links_search: null
      });

    case 'RECEIVE_UNMAPPED_FILES':
      return _objectSpread(_objectSpread({}, state), {}, {
        unmappedFiles: action.data
      });

    case 'RECEIVE_UNMAPPED_FILE_STATISTICS':
      return _objectSpread(_objectSpread({}, state), {}, {
        unmappedFileCount: action.data.count,
        unmappedFileSize: action.data.totalSize
      });

    case 'RECEIVE_FILES_TO_MAP':
      return _objectSpread(_objectSpread({}, state), {}, {
        filesToMap: action.data
      });

    case 'RESET_SUBMISSION_STATUS':
      return _objectSpread(_objectSpread({}, state), {}, {
        submit_entity_counts: [],
        submit_result: null,
        submit_result_string: '',
        submit_status: 0,
        submit_counter: 0,
        submit_total: 0
      });

    default:
      return state;
  }
};

var reducers = (0, _redux.combineReducers)({
  submission: submission,
  ddgraph: _reducers.default,
  versionInfo: versionInfo
});
var _default = reducers;
exports.default = _default;